BindResultLogError

Enum BindResultLogError 

pub enum BindResultLogError {
    Open(Error),
    Read(Error),
    Parse(usize, Error),
}
Error type for load_bind_result_log failures.

Variants



Open(Error)

The log file could not be opened (missing, permission denied, etc.).



Read(Error)

A line could not be read from the file.



Parse(usize, Error)

A line in the log was not valid JSON for BindResultEntry. Contains the line number (1-based) and the raw parse error.